# Example Package

This is a highky opinionated framework for developing applications.

I have been using bits and pieces of this for over two decades. This
is a very early release of code that I am origanizing and documenting
for use by others.
